pub enum ConfigValueError {
NotPresent(String),
NotUnicode(String),
}Expand description
Failure resolving a ConfigValue::Env reference.
Variants
NotPresent(String)
The named environment variable is not set in the process.
NotUnicode(String)
The named environment variable is set but contains non-UTF-8 bytes.