IdentityDef

Struct IdentityDef 

pub struct IdentityDef {
    pub name: &'static str,
    pub schema: Option<&'static str>,
    pub type_: IdentityType,
    pub increment: Option<&'static str>,
    pub min_value: Option<&'static str>,
    pub max_value: Option<&'static str>,
    pub start_with: Option<&'static str>,
    pub cache: Option<i32>,
    pub cycle: bool,
}
The GENERATED ... AS IDENTITY part of a ColumnDef, with the options of its backing sequence. Numeric options are SQL literals stored as strings, so they can hold any bigint.

Fields

name: &'static str

Name of the backing sequence

schema: Option<&'static str>

Schema of the backing sequence

type_: IdentityType

ALWAYS or BY DEFAULT

increment: Option<&'static str>

INCREMENT BY

min_value: Option<&'static str>

MINVALUE

max_value: Option<&'static str>

MAXVALUE

start_with: Option<&'static str>

START WITH

cache: Option<i32>

CACHE

cycle: bool

CYCLE

Implementations

Source

impl IdentityDef

pub const fn new(name: &'static str, type_: IdentityType) -> Self

Creates an identity backed by the sequence name, with default options.

pub const fn schema(self, schema: &'static str) -> Self

Sets the sequence’s schema.

pub const fn increment(self, value: &'static str) -> Self

Sets INCREMENT BY.

pub const fn min_value(self, value: &'static str) -> Self

Sets MINVALUE.

pub const fn max_value(self, value: &'static str) -> Self

Sets MAXVALUE.

pub const fn start_with(self, value: &'static str) -> Self

Sets START WITH.

pub const fn cache(self, value: i32) -> Self

Sets CACHE.

pub const fn cycle(self) -> Self

Sets CYCLE.

pub const fn into_identity(self) -> Identity

Converts to the runtime Identity.